// $Id$
//
//  Copyright (C) 2004-2006 Rational Discovery LLC
//
//  @@ All Rights Reserved @@
//  This file is part of the RDKit.
//  The contents are covered by the terms of the BSD license
//  which is included in the file license.txt, found at the root
//  of the RDKit source tree.
//

#include "CatalogEntry.h"

namespace RDCatalog {
CatalogEntry::~CatalogEntry() {}
}  // namespace RDCatalog
